/* ============================================================
 *
 * This file is a part of educazionik project
 * http://educazionik.sourceforge.net/
 *
 * Date        : 13-8-2002
 * Description : qlabeldrag
 *
 * Copyright 2002-2009 by Nicola De Filippo <nicola@nicoladefilippo.it>
 * Copyright 2009      by Angelo Naselli    <anaselli at linux dot it>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#include "qlabeldrag.h"
#include <QDebug>
#include <QDrag>
#include <QMouseEvent>

 LabelDrag::LabelDrag( QWidget * parent, Qt::WindowFlags f) :
    QLabel(parent, f )
{
    setAcceptDrops( true );
    setFrameShadow(QFrame::Raised);
    setFrameShape(QFrame::Panel);
    QPalette backg(QPalette::Background, QColor(255,255,255));
    setPalette(backg);

    _drag = false;
    _changeText = false;
    show();
}


 void LabelDrag::dragEnterEvent(QDragEnterEvent *event)
 {
     if (event->mimeData()->hasFormat("text/plain"))
         event->acceptProposedAction();
 }



void LabelDrag::mousePressEvent( QMouseEvent *evt )
{

    if (evt->button() == Qt::LeftButton) {
        if(_drag) {
            QDrag *drag = new QDrag(this);
            QMimeData *mimeData = new QMimeData;

            mimeData->setText(this->text());
            drag->setMimeData(mimeData);
            Qt::DropAction dropAction = drag->exec();
        }
    }
}


void LabelDrag::setDragging(bool drag)
{
        _drag = drag;
}


void LabelDrag::setChangeText(bool change)
{
    _changeText = change;
}

void LabelDrag::dropEvent( QDropEvent *evt )
{
    if(_changeText)
        this->setText(evt->mimeData()->text());

    emit dropReceived((QLabel *)(evt->source()), (QLabel *)this);
    evt->acceptProposedAction();
}

