/* ============================================================
 *
 * This file is a part of educazionik project
 * http://educazionik.sourceforge.net/
 *
 * Date        : 13-8-2002
 * Description : Difficolta' ortografiche implementation
 *
 * Copyright 2002-2009 by Nicola De Filippo <nicola@nicoladefilippo.it>
 * Copyright 2009      by Angelo Naselli    <anaselli at linux dot it>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * ============================================================ */
#include "windowaggettivi.h"
#include "ui_windowaggettivi.h"
#include <QMessageBox>
#include <QSettings>

#include "aboutdlg.h"
#include "dueaggettivi_version.h"

WindowAggettivi::WindowAggettivi(QWidget *parent)
    : QMainWindow(parent), ui(new Ui::WindowAggettivi)
{
  ui->setupUi(this);
  QString title     = QString(APPL_NAME) + " V. " + QString(APPL_VERSION);

  setWindowTitle(title);
  setWindowIcon(QIcon( QPixmap(QString(DATA_DIR) + "/educazionik.png")));
  
  
  coppie = new accoppiamenti(QString(DATA_DIR) + "/dueaggettivi.txt", 9);


  ui->label_1->setDragging(true);
  ui->label_3->setDragging(true);
  ui->label_5->setDragging(true);
  ui->label_7->setDragging(true);
  ui->label_9->setDragging(true);
  ui->label_11->setDragging(true);
  ui->label_13->setDragging(true);
  ui->label_15->setDragging(true);
  ui->label_17->setDragging(true);

  connect(ui->label_2, SIGNAL(dropReceived(QLabel *, QLabel *)), this, SLOT(actionDrop(QLabel*,QLabel*)));
  connect(ui->label_4, SIGNAL(dropReceived(QLabel *, QLabel *)), this, SLOT(actionDrop(QLabel*,QLabel*)));
  connect(ui->label_6, SIGNAL(dropReceived(QLabel *, QLabel *)), this, SLOT(actionDrop(QLabel*,QLabel*)));
  connect(ui->label_8, SIGNAL(dropReceived(QLabel *, QLabel *)), this, SLOT(actionDrop(QLabel*,QLabel*)));
  connect(ui->label_10, SIGNAL(dropReceived(QLabel *, QLabel *)), this, SLOT(actionDrop(QLabel*,QLabel*)));
  connect(ui->label_12, SIGNAL(dropReceived(QLabel *, QLabel *)), this, SLOT(actionDrop(QLabel*,QLabel*)));
  connect(ui->label_14, SIGNAL(dropReceived(QLabel *, QLabel *)), this, SLOT(actionDrop(QLabel*,QLabel*)));
  connect(ui->label_16, SIGNAL(dropReceived(QLabel *, QLabel *)), this, SLOT(actionDrop(QLabel*,QLabel*)));
  connect(ui->label_18, SIGNAL(dropReceived(QLabel *, QLabel *)), this, SLOT(actionDrop(QLabel*,QLabel*)));

  indovinati = 0;
  loadSetting();

  avanti();
}

WindowAggettivi::~WindowAggettivi()
{
    delete ui;
    delete coppie;
}

void WindowAggettivi::loadSetting()
{
  QSettings settings("Educazionik", APPL_NAME);
  
  QString exercise_color = settings.value("exercise-color").toString();
  QString exercise_bgcolor = settings.value("exercise-backgroundcolor").toString();
  QString solved_color = settings.value("solved-color").toString();
  //TODO border for the selected labelDrag... using keyboard
  
  qApp->setStyleSheet("LabelDrag {color: "             + exercise_color   +
                      "; background-color: "           + exercise_bgcolor + 
                      ";} LabelDrag:disabled {color: " + solved_color +
                      ";} ");
}

void WindowAggettivi::saveSettings()
{
  QSettings settings("Educazionik", APPL_NAME);

  //   TODO: implement and manage

}

void WindowAggettivi::info()
{
  QString title     = QString(APPL_NAME) + " V. " + QString(APPL_VERSION);
 
  QString description = "Programma di esercizi per l'abbinamento degli aggettivi";
  QString icon = QString(RESOURCE_DIR) + "/logo.png";

  AboutDialog about(this, title, "", description, icon, "", "", "");
  about.exec();
}

void WindowAggettivi::azzera()
{
    ui->lcdNumber->display(0);
    ui->lcdNumber_2->display(0);
    avanti();
}

void WindowAggettivi::avanti()
{
    QString a[9],b[9];

    if (coppie->errore()!=-1) {


        coppie->frase(&a[0],&b[0]);

        ui->label_1->setText(a[0]);
        ui->label_3->setText(a[1]);
        ui->label_5->setText(a[2]);
        ui->label_7->setText(a[3]);
        ui->label_9->setText(a[4]);
        ui->label_11->setText(a[5]);
        ui->label_13->setText(a[6]);
        ui->label_15->setText(a[7]);
        ui->label_17->setText(a[8]);

        ui->label_2->setText(b[0]);
        ui->label_4->setText(b[1]);
        ui->label_6->setText(b[2]);
        ui->label_8->setText(b[3]);
        ui->label_10->setText(b[4]);
        ui->label_12->setText(b[5]);
        ui->label_14->setText(b[6]);
        ui->label_16->setText(b[7]);
        ui->label_18->setText(b[8]);

        ui->pushButtonAvanti->setEnabled(false);

        ui->label_1->setEnabled(true);
        ui->label_3->setEnabled(true);
        ui->label_5->setEnabled(true);
        ui->label_7->setEnabled(true);
        ui->label_9->setEnabled(true);
        ui->label_11->setEnabled(true);
        ui->label_13->setEnabled(true);
        ui->label_15->setEnabled(true);
        ui->label_17->setEnabled(true);

        ui->label_2->setEnabled(true);
        ui->label_4->setEnabled(true);
        ui->label_6->setEnabled(true);
        ui->label_8->setEnabled(true);
        ui->label_10->setEnabled(true);
        ui->label_12->setEnabled(true);
        ui->label_14->setEnabled(true);
        ui->label_16->setEnabled(true);
        ui->label_18->setEnabled(true);


        indovinati = 0;
    }
    else {
        ui->pushButtonAzzera->setEnabled(false);
        ui->pushButtonAvanti->setEnabled(false);
        QMessageBox::critical( 0, "Aggettivi 1.0", QString("Non riesco a trovare il file " + QString(DATA_DIR) + "/dueaggettivi.txt "));
    }
}




void WindowAggettivi::actionDrop(QLabel *left, QLabel *right)
{
    QString sum;

    if ((coppie->esatto(left->text(), right->text())) > -1) {
        sum = left->text() + " " + right->text();
        right->setText(sum);
        ui->lcdNumber->display(ui->lcdNumber->intValue() + 1);
        ui->labelIcon->setPixmap(QPixmap(QString(RESOURCE_DIR) + "/smile.png"));
        if(++indovinati == 9)
            ui->pushButtonAvanti->setEnabled(true);
        left->setEnabled(false);
        right->setEnabled(false);
    }
    else {
        ui->lcdNumber_2->display(ui->lcdNumber_2->intValue()+1);
        ui->labelIcon->setPixmap(QPixmap(QString(RESOURCE_DIR) + "/frown.png"));
    }
}

