/* ============================================================
 *
 * This file is a part of educazionik project
 * http://educazionik.sourceforge.net/
 *
 * Date        : 13-8-2002
 * Description : Lessico implementation
 *
 * Copyright 2002-2009 by Nicola De Filippo <nicola@nicoladefilippo.it>
 * Copyright 2009      by Angelo Naselli    <anaselli at linux dot it>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#include<qmessagebox.h>
#include<time.h>
#include "form5.h"
#include "ui_form5.h"
#include "sinonimicontrari.h"
#include "lessico_version.h"

struct privateForm5
{
    sinonimiContrari *scelta;
    QString title;
    QString file_sinonimi;
    QString file_contrari;
     
    privateForm5() : scelta(NULL) {}
    ~privateForm5()
    {
      if (scelta)
        delete scelta;
    }
};

Form5::Form5(QWidget *parent)
        : QDialog(parent), ui(new Ui::Form5), d(new privateForm5)
{
  ui->setupUi(this);
  d->title = QString(APPL_NAME)    + " V. " +
              QString(APPL_VERSION) + " "    +
              QString(APPL_DATE)    + " "    +
              QString(APPL_TIME);
  d->file_sinonimi = QString(DATA_DIR) + "/sinonimi.txt";
  d->file_contrari = QString(DATA_DIR) + "/contrari.txt";

  setWindowTitle("Sinonimi e contrari");
  
  connect(ui->m_resultTable->m_exit, SIGNAL(pressed()), this, SLOT(esci()));
  connect(ui->m_resultTable->m_go_on, SIGNAL(pressed()), this, SLOT(avanti()));
  connect(ui->m_resultTable->m_resetButton, SIGNAL(pressed()), this, SLOT(azzera()));
}

Form5::~Form5()
{
    delete ui;
    delete d;
}

void Form5::init()
{
    if (!d->scelta)
      d->scelta=new sinonimiContrari(d->file_sinonimi, d->file_contrari);

    if (d->scelta->errore()!=-1)
    {
      azzera();
    }
    else
    {      
      QMessageBox::critical( 0, d->title, QString("Non riesco a trovare il file ") + 
                             d->file_contrari + QString(" o ") + d->file_sinonimi);
      // Diamo la possibilità di ricaricare il file se non trovato
      delete d->scelta;
      d->scelta = NULL;
    }
}

void Form5::azzera()
{
  avanti();
  ui->m_resultTable->LCD_Wrong->display(0);
  ui->m_resultTable->LCD_Correct->display(0);
}
void Form5::avanti()
{
    QString a[2];
    d->scelta->frase(&a[0],&a[1]);
    ui->textLabel1->setText(a[0]+ " / "+a[1]);

    QPalette palette;
    palette.setColor(ui->pushButton34->backgroundRole(), QColor( 255, 255, 255 ));
    ui->pushButton34->setPalette(palette);
    palette.setColor(ui->pushButton35->backgroundRole(), QColor( 255, 255, 255 ));
    ui->pushButton35->setPalette(palette);

    ui->m_resultTable->m_go_on->setEnabled(false);
    ui->pushButton35->setEnabled(true);
    ui->pushButton34->setEnabled(true);
}

void Form5::esci()
{
     this->accept();
}



void Form5::sinonimi()
{
    if (!d->scelta->esatto(1))
    {
        ui->m_resultTable->LCD_Correct->display(ui->m_resultTable->LCD_Correct->intValue()+1);
        QPalette palette;
        palette.setColor(ui->pushButton34->backgroundRole(), QColor( 255, 255, 255 ));
        ui->pushButton34->setPalette(palette);

        ui->m_resultTable->m_go_on->setEnabled(true);
        ui->pushButton35->setEnabled(false);
        ui->pushButton34->setEnabled(false);
    }
    else
        ui->m_resultTable->LCD_Wrong->display(ui->m_resultTable->LCD_Wrong->intValue()+1);
}



void Form5::contrari()
{
    if (!d->scelta->esatto(2))
    {
        ui->m_resultTable->LCD_Correct->display(ui->m_resultTable->LCD_Correct->intValue()+1);
        QPalette palette;
        palette.setColor(ui->pushButton35->backgroundRole(), QColor( 255, 255, 255 ));
        ui->pushButton35->setPalette(palette);

        ui->m_resultTable->m_go_on->setEnabled(true);
        ui->pushButton35->setEnabled(false);
        ui->pushButton34->setEnabled(false);
    }
    else
        ui->m_resultTable->LCD_Wrong->display(ui->m_resultTable->LCD_Wrong->intValue()+1);
}



