/* ============================================================
 *
 * This file is a part of educazionik project
 * http://educazionik.sourceforge.net/
 *
 * Date        : 13-8-2002
 * Description : Lessico implementation
 *
 * Copyright 2002-2009 by Nicola De Filippo <nicola@nicoladefilippo.it>
 * Copyright 2009      by Angelo Naselli    <anaselli at linux dot it>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#include<qmessagebox.h>
#include<time.h>
#include "form8.h"
#include "ui_form8.h"
#include "accoppiamenti.h"
#include "lessico_version.h"

struct privateForm8
{
    accoppiamenti *coppie;
    int indovinati;
    QString title;
    QString filename;
    
    privateForm8() : coppie(NULL) {}
    ~privateForm8()
    {
      if (coppie)
        delete coppie;
    }
};

Form8::Form8(QWidget *parent)
        : QDialog(parent), ui(new Ui::Form8), d(new privateForm8)
{
  ui->setupUi(this);
  d->title = QString(APPL_NAME)    + " V. " +
              QString(APPL_VERSION) + " "    +
              QString(APPL_DATE)    + " "    +
              QString(APPL_TIME);
  d->filename = QString(DATA_DIR) + "/gradi.txt";
  
  setWindowTitle(trUtf8("Livello d'intensità delle parole"));
  
  connect(ui->m_resultTable->m_exit, SIGNAL(pressed()), this, SLOT(esci()));
  connect(ui->m_resultTable->m_go_on, SIGNAL(pressed()), this, SLOT(avanti()));
  connect(ui->m_resultTable->m_resetButton, SIGNAL(pressed()), this, SLOT(azzera()));

  connect(ui->lineEdit124, SIGNAL(dropReceived(QLabel *, QLabel *)), this, SLOT(action_drop(QLabel*,QLabel*)));
  connect(ui->lineEdit125, SIGNAL(dropReceived(QLabel *, QLabel *)), this, SLOT(action_drop(QLabel*,QLabel*)));
}

Form8::~Form8()
{
    delete ui;
    delete d;
}

void Form8::init()
{
    QString a,b;
    int j;

    if (!d->coppie)
      d->coppie=new accoppiamenti(d->filename,1);
    
    srand(time(0));
    if (d->coppie->errore()!=-1)
    {
      d->coppie->frase(&a,&b);
      j=(int) ((double)2*rand()/(RAND_MAX));
      QPalette palette;
      palette.setColor(ui->lineEdit123->foregroundRole(), QColor( 0, 0, 0 ));
      ui->lineEdit123->setPalette(palette);
      palette.setColor(ui->lineEdit126->foregroundRole(), QColor( 0, 0, 0 ));
      ui->lineEdit126->setPalette(palette);
      if (j==1)
      {
          ui->lineEdit123->setText(a);
          ui->lineEdit126->setText(b);
      }
      else
      {
          ui->lineEdit123->setText(b);
          ui->lineEdit126->setText(a);
      }
      ui->lineEdit125->setText("");
      ui->lineEdit124->setText("");


      ui->m_resultTable->m_go_on->setEnabled(false);
      ui->lineEdit123->setEnabled(true);
      ui->lineEdit124->setEnabled(true);
      ui->lineEdit125->setEnabled(true);
      ui->lineEdit126->setEnabled(true);

      ui->lineEdit123->setDragging(true);
      ui->lineEdit126->setDragging(true);

      ui->m_resultTable->LCD_Wrong->display(0);
      ui->m_resultTable->LCD_Correct->display(0);
      d->indovinati=0;
    }
    else
    {
      QMessageBox::critical( 0, d->title, QString("Non riesco a trovare il file ") + d->filename);
       // Diamo la possibilità di ricaricare il file se non trovato
      delete d->coppie;
      d->coppie = NULL;
    }
    d->indovinati=0;
}

void Form8::azzera()
{
    ui->m_resultTable->LCD_Wrong->display(0);
    ui->m_resultTable->LCD_Correct->display(0);
   
    avanti();
}

void Form8::avanti()
{
    QString a,b;
    int j;

    d->coppie->frase(&a,&b);
    QPalette palette;
    palette.setColor(ui->lineEdit123->foregroundRole(), QColor( 0, 0, 0 ));
    ui->lineEdit123->setPalette(palette);
    palette.setColor(ui->lineEdit126->foregroundRole(), QColor( 0, 0, 0 ));
    ui->lineEdit126->setPalette(palette);
    palette.setColor(ui->lineEdit125->foregroundRole(), QColor( 0, 0, 0 ));
    ui->lineEdit125->setPalette(palette);
    palette.setColor(ui->lineEdit124->foregroundRole(), QColor( 0, 0, 0 ));
    ui->lineEdit124->setPalette(palette);
    
    j=(int) ((double)2*rand()/(RAND_MAX));
    palette.setColor(ui->lineEdit123->foregroundRole(), QColor( 0, 0, 0 ));
    ui->lineEdit123->setPalette(palette);
    palette.setColor(ui->lineEdit126->foregroundRole(), QColor( 0, 0, 0 ));
    ui->lineEdit126->setPalette(palette);
    if (j==1)
    {
        ui->lineEdit123->setText(a);
        ui->lineEdit126->setText(b);
    }
    else
    {
        ui->lineEdit123->setText(b);
        ui->lineEdit126->setText(a);
    }
    ui->lineEdit125->setText("");
    ui->lineEdit124->setText("");

   ui->m_resultTable->m_go_on->setEnabled(false);

    ui->lineEdit123->setEnabled(true);
    ui->lineEdit124->setEnabled(true);
    ui->lineEdit125->setEnabled(true);
    ui->lineEdit126->setEnabled(true);

    ui->lineEdit123->setDragging(true);
    ui->lineEdit126->setDragging(true);
    
    d->indovinati=0;
}

void Form8::esci()
{
  ui->m_resultTable->m_go_on->setEnabled(false);
  d->indovinati=0;
  this->accept();
}

void Form8::action_drop( QLabel *a, QLabel *b )
{
  QString meno_in,piu_in,dum;
  int caso=0;

  if (a->objectName() == "lineEdit123" && 
      b->objectName() == "lineEdit124")
  {
      meno_in=ui->lineEdit126->text();
      piu_in=ui->lineEdit123->text();
      caso=1;
  }
  else if (a->objectName() == "lineEdit126" && 
            b->objectName() == "lineEdit125")
  {
      meno_in=ui->lineEdit126->text();
      piu_in=ui->lineEdit123->text();
      caso=2;
  }
  else if (a->objectName() == "lineEdit123" && 
            b->objectName() == "lineEdit125")
  {
      meno_in=ui->lineEdit123->text();
      piu_in=ui->lineEdit126->text();
      caso=3;
  }
  else if (a->objectName() == "lineEdit126" && 
            b->objectName() == "lineEdit124")
  {
      meno_in=ui->lineEdit123->text();
      piu_in=ui->lineEdit126->text();
      caso=4;
  }

  if ((d->coppie->esatto(meno_in,piu_in)>-1))
  {
    QPalette palette;
    switch (caso)
    {
      case 1:
        palette.setColor(ui->lineEdit123->foregroundRole(), QColor( 255, 255, 255));
        ui->lineEdit123->setPalette(palette);
        ui->lineEdit124->setText(piu_in);
        ui->lineEdit123->setDragging(false);
      break;
      case 2:
        palette.setColor(ui->lineEdit126->foregroundRole(), QColor( 255, 255, 255));
        ui->lineEdit126->setPalette(palette);
        ui->lineEdit125->setText(meno_in);
        ui->lineEdit126->setDragging(false);
        break;
      case 3:
        palette.setColor(ui->lineEdit123->foregroundRole(), QColor( 255, 255, 255));
        ui->lineEdit123->setPalette(palette);
        ui->lineEdit125->setText(meno_in);
        ui->lineEdit123->setDragging(false);
        break;
      case 4:
        palette.setColor(ui->lineEdit126->foregroundRole(), QColor( 255, 255, 255));
        ui->lineEdit126->setPalette(palette);
        ui->lineEdit124->setText(piu_in);
        ui->lineEdit126->setDragging(false);
        break;
      default:
        break;
    }

    ui->m_resultTable->LCD_Correct->display(ui->m_resultTable->LCD_Correct->intValue()+1);
    if (++d->indovinati ==2)
        ui->m_resultTable->m_go_on->setEnabled(true);

  }
  else
  {
      ui->m_resultTable->LCD_Wrong->display(ui->m_resultTable->LCD_Wrong->intValue()+1);
  }
}
