/* ============================================================
 *
 * This file is a part of educazionik project
 * http://educazionik.sourceforge.net/
 *
 * Date        : 13-8-2002
 * Description : Lessico implementation
 *
 * Copyright 2002-2009 by Nicola De Filippo <nicola@nicoladefilippo.it>
 * Copyright 2009      by Angelo Naselli    <anaselli at linux dot it>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#include<qmessagebox.h>
#include<time.h>
#include "form9.h"
#include "ui_form9.h"
#include "quadrupla.h"
#include "lessico_version.h"

struct privateForm9
{
    quadrupla *scelta;
    QString title;
    QString filename;
    
    privateForm9() : scelta(NULL) {}
    ~privateForm9()
    {
      if (scelta)
        delete scelta;
    }

};

Form9::Form9(QWidget *parent)
        : QDialog(parent), ui(new Ui::Form9), d(new privateForm9)
{
  ui->setupUi(this);

  d->title = QString(APPL_NAME)    + " V. " +
                QString(APPL_VERSION) + " "    +
                QString(APPL_DATE)    + " "    +
                QString(APPL_TIME);
  d->filename = QString(DATA_DIR) + "/aree1.txt";

  setWindowTitle("Parole che comprendono le altre");
  ui->m_aim_label->setText("Clicca sul nome che comprende gli altri");

  connect(ui->m_resultTable->m_exit, SIGNAL(pressed()), this, SLOT(esci()));
  connect(ui->m_resultTable->m_go_on, SIGNAL(pressed()), this, SLOT(avanti()));
  connect(ui->m_resultTable->m_resetButton, SIGNAL(pressed()), this, SLOT(azzera()));
}

Form9::~Form9()
{
  delete ui;
  delete d;
}

void Form9::init()
{
  QString a[4];
    
  if (!d->scelta)
    d->scelta=new quadrupla(d->filename);

  if (d->scelta->errore()!=-1)
  {
    azzera();
  }
  else
  {
    QMessageBox::critical( 0, d->title, QString("Non riesco a trovare il file ") + d->filename);
      // Diamo la possibilità di ricaricare il file se non trovato
    delete d->scelta;
    d->scelta = NULL;
  }
}

void Form9::azzera()
{
    avanti();
    ui->m_resultTable->LCD_Wrong->display(0);
    ui->m_resultTable->LCD_Correct->display(0);
}

void Form9::avanti()
{
    QString a[4];
    d->scelta->frase(&a[0]);
    ui->pushButton4->setText(a[0]);
    ui->pushButton5->setText(a[1]);
    ui->pushButton6->setText(a[2]);
    ui->pushButton7->setText(a[3]);
    QPalette palette;
    palette.setColor(ui->pushButton4->backgroundRole(), QColor( 255, 255, 255 ));
    ui->pushButton4->setPalette(palette);
    palette.setColor(ui->pushButton5->backgroundRole(), QColor( 255, 255, 255 ));
    ui->pushButton5->setPalette(palette);
    palette.setColor(ui->pushButton6->backgroundRole(), QColor( 255, 255, 255 ));
    ui->pushButton6->setPalette(palette);
    palette.setColor(ui->pushButton7->backgroundRole(), QColor( 255, 255, 255 ));
    ui->pushButton7->setPalette(palette);

    ui->pushButton4->setEnabled(true);
    ui->pushButton5->setEnabled(true);
    ui->pushButton6->setEnabled(true);
    ui->pushButton7->setEnabled(true);
   ui->m_resultTable->m_go_on->setEnabled(false);
}

void Form9::esci()
{
   ui->m_resultTable->m_go_on->setEnabled(false);
   this->accept();
}

void Form9::primo()
{
  if (d->scelta->esatto(ui->pushButton4->text())>-1)
  {
    ui->m_resultTable->LCD_Correct->display(ui->m_resultTable->LCD_Correct->intValue()+1);
    QPalette palette;
    palette.setColor(ui->pushButton4->backgroundRole(), QColor( 255, 255, 255 ));
    ui->pushButton4->setPalette(palette);

    ui->m_resultTable->m_go_on->setEnabled(true);
    ui->pushButton4->setEnabled(false);
    ui->pushButton5->setEnabled(false);
    ui->pushButton6->setEnabled(false);
    ui->pushButton7->setEnabled(false);
  }
  else
    ui->m_resultTable->LCD_Wrong->display(ui->m_resultTable->LCD_Wrong->intValue()+1);
}

void Form9::secondo()
{
  if (d->scelta->esatto(ui->pushButton5->text())>-1)
  {
    ui->m_resultTable->LCD_Correct->display(ui->m_resultTable->LCD_Correct->intValue()+1);
    ui->m_resultTable->m_go_on->setEnabled(true);
    QPalette palette;
    palette.setColor(ui->pushButton5->backgroundRole(), QColor( 255, 255, 255 ));
    ui->pushButton5->setPalette(palette);
    ui->pushButton4->setEnabled(false);
    ui->pushButton5->setEnabled(false);
    ui->pushButton6->setEnabled(false);
    ui->pushButton7->setEnabled(false);
  }
  else
    ui->m_resultTable->LCD_Wrong->display(ui->m_resultTable->LCD_Wrong->intValue()+1);
}

void Form9::terzo()
{
  if (d->scelta->esatto(ui->pushButton6->text())>-1)
  {
    ui->m_resultTable->LCD_Correct->display(ui->m_resultTable->LCD_Correct->intValue()+1);
    QPalette palette;
    palette.setColor(ui->pushButton6->backgroundRole(), QColor( 255, 255, 255 ));
    ui->pushButton6->setPalette(palette);
    ui->m_resultTable->m_go_on->setEnabled(true);
    ui->pushButton4->setEnabled(false);
    ui->pushButton5->setEnabled(false);
    ui->pushButton6->setEnabled(false);
    ui->pushButton7->setEnabled(false);
  }
  else
    ui->m_resultTable->LCD_Wrong->display(ui->m_resultTable->LCD_Wrong->intValue()+1);
}

void Form9::quarto()
{
  if (d->scelta->esatto(ui->pushButton7->text())>-1)
  {
    ui->m_resultTable->LCD_Correct->display(ui->m_resultTable->LCD_Correct->intValue()+1);
    QPalette palette;
    palette.setColor(ui->pushButton7->backgroundRole(), QColor( 255, 255, 255 ));
    ui->pushButton7->setPalette(palette);
    ui->m_resultTable->m_go_on->setEnabled(true);
    ui->pushButton4->setEnabled(false);
    ui->pushButton5->setEnabled(false);
    ui->pushButton6->setEnabled(false);
    ui->pushButton7->setEnabled(false);
  }
  else
    ui->m_resultTable->LCD_Wrong->display(ui->m_resultTable->LCD_Wrong->intValue()+1);
}
