/* ============================================================
 *
 * This file is a part of educazionik project
 * http://educazionik.sourceforge.net/
 *
 * Date        : 4/6/2003
 * Description : Uso H implementation
 *
 * Copyright 2003-2009 by Nicola De Filippo <nicola@nicoladefilippo.it>
 * Copyright 2009      by Angelo Naselli    <anaselli at linux dot it>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * ============================================================ */
#include "dialogplay.h"
#include "ui_dialogplay.h"
#include <QMessageBox>
#include <QPalette>

#include "usoh_version.h"

DialogPlay::DialogPlay(QWidget *parent)
    : QDialog(parent), ui(new Ui::DialogPlay), pdiff(NULL)
{
  ui->setupUi(this);
  ui->m_text->setWordWrap(true);
  
  QPalette palette;

  palette.setColor(ui->LCD_Wrong->foregroundRole(), QColor( 170, 0, 0 ));
  ui->LCD_Wrong->setPalette(palette);
  ui->LCD_Wrong->setSegmentStyle( QLCDNumber::Filled );

  palette.setColor(ui->LCD_Correct->foregroundRole(), QColor( 0, 170, 0 ));
  ui->LCD_Correct->setPalette(palette);
  ui->LCD_Correct->setSegmentStyle( QLCDNumber::Filled );

  palette.setColor(ui->CorrectLabel->foregroundRole(), QColor( 0, 170, 0 ));
  ui->CorrectLabel->setPalette(palette);

  palette.setColor(ui->WrongLabel->foregroundRole(), QColor( 170, 0, 0 ));
  ui->WrongLabel->setPalette(palette);

}

void DialogPlay::game(QString type, bool how)
{
    QString path,destro,sinistro,quiz;
    int pos;
    automatico = how;

    ui->LCD_Correct->display(0);
    ui->LCD_Wrong->display(0);
    ui->PushButton34->setEnabled(false);
    ui->PushButton32->setEnabled(true);
    ui->PushButton33->setEnabled(true);
    ui->PushButton35->setDown(false);

    if(automatico)
      ui->PushButton34->hide();
    else
      ui->PushButton34->show();


    path=DATA_DIR;
    sinistro = type.section(' ',0,0);
    destro = type.section(' ',1,1);

    this->setWindowTitle(type);

    pdiff= new s_diff(sinistro,destro);

    if(!pdiff->errore())
    {
      quiz=pdiff->frase();

      ui->PushButton32->setText(sinistro);
      ui->PushButton33->setText(destro);
      pos = quiz.indexOf(",");
      ui->m_text->setText(quiz.replace(pos,1," ___ "));
      QDialog::exec();
    }
    else
    {
      ui->PushButton32->hide();
      ui->PushButton33->hide();
      ui->PushButton34->hide();
 
      QMessageBox::warning( this, QString(APPL_NAME),
        "Non trovato il file contenente i dati in " + path);

    }
}


void DialogPlay::avanti()
{
    QString quiz;
    int pos;
    
    quiz=pdiff->frase();
    pos = quiz.indexOf(",");
    ui->m_text->setText(quiz.replace(pos,1," ___ "));

    ui->PushButton34->setEnabled(false);
    ui->PushButton32->setEnabled(true);
    ui->PushButton33->setEnabled(true);
}

void DialogPlay::destro()
{
    QString frase;

    if(ui->PushButton33->text()==pdiff->esatto())
    {
      frase = ui->m_text->text();
      frase = frase.replace("___", ui->PushButton33->text());

      ui->LCD_Correct->display(ui->LCD_Correct->intValue()+1);
      ui->m_text->setText(frase);
      ui->PushButton34->setEnabled(true);
      ui->PushButton32->setEnabled(false);
      ui->PushButton33->setEnabled(false);

      ui->TextLabel4->setPixmap(QPixmap(QString(RESOURCE_DIR) + "/smile.png"));

      if(automatico) this->avanti();
    }
    else
    {
      ui->LCD_Wrong->display(ui->LCD_Wrong->intValue()+1);
      ui->TextLabel4->setPixmap(QPixmap(QString(RESOURCE_DIR) + "/frown.png"));
    }
}



void DialogPlay::azzera()
{
    ui->LCD_Correct->display(0);
    ui->LCD_Wrong->display(0);
    avanti();
}

void DialogPlay::sinistro()
{
    QString frase;

    if(ui->PushButton32->text()==pdiff->esatto())
    {
      frase=ui->m_text->text();
      frase=frase.replace("___", ui->PushButton32->text());
      ui->LCD_Correct->display(ui->LCD_Correct->intValue()+1);
      ui->m_text->setText(frase);
      ui->PushButton34->setEnabled(true);
      ui->PushButton32->setEnabled(false);
      ui->PushButton33->setEnabled(false);

      ui->TextLabel4->setPixmap(QPixmap(QString(RESOURCE_DIR) + "/smile.png"));

      if(automatico) this->avanti();
    }
    else
    {
      ui->LCD_Wrong->display(ui->LCD_Wrong->intValue()+1);
      ui->TextLabel4->setPixmap(QPixmap(QString(RESOURCE_DIR) + "/frown.png"));
    }
}



DialogPlay::~DialogPlay()
{
    delete ui;
    delete pdiff;
}

